#!/bin/sh
# Script used to create DB base backup

if [ $# -ne 2 ]; then
  echo "Usage: $0 db_base_file db_xlog_file"
  exit 1
fi

BASE_FILE=$1
XLOG_FILE=$2
source /etc/profile
PG_PATH="$CMS_HOME/postgresql"
DB_BACKUP_PATH="$CMS_HOME/db_backup"
PSQL_CMD="$PG_PATH/bin/psql"
PCTL_CMD="$PG_PATH/bin/pg_ctl"
DB_DIR="$PG_PATH/data"
ARCHIVE_DIR="$PG_PATH/archive"
BIP="$PG_PATH/backup_in_progress"
export LD_LIBRARY_PATH="$PG_PATH/lib/"

TRIGGER_FILE="trigger"
START_BKUP_SQL="SELECT pg_start_backup('clone',true)"
STOP_BKUP_SQL="SELECT pg_stop_backup()"

if [ ! -d $DB_BACKUP_PATH ]; then
  mkdir -p $DB_BACKUP_PATH
fi

if [ ! -d $DB_DIR ]; then
  echo "$DB_DIR is not a directory"
  exit 1
fi

if [ -f $BASE_FILE ]; then
  echo "Removing $BASE_FILE"
  rm -f $BASE_FILE
fi
if [ -f $XLOG_FILE ]; then
  echo "Removing $XLOG_FILE"
  rm -f $XLOG_FILE
fi

rm -f $ARCHIVE_DIR/*

function backup_data()
{
  tar -czf $BASE_FILE -C $PG_PATH data --exclude postmaster.pid --exclude recovery.* --exclude $TRIGGER_FILE --exclude pg_xlog
  return $?
}

function backup_log()
{
  tar -czf $XLOG_FILE -C $PG_PATH archive
  return $?
}

# Check whether the Postgresql is running
status=`su postgres -c "$PCTL_CMD status -D $DB_DIR" | grep "PID"`
if [ "$status" ]; then
  touch $BIP
  su postgres -c "$PSQL_CMD -c \"$START_BKUP_SQL\""
  result=$?
  if [ $result -eq 0 ]; then
     backup_data;
  fi
  su postgres -c "$PSQL_CMD -c \"$STOP_BKUP_SQL\""
  rm -f $BIP
  if [ $? -ne 0 ]; then
    exit 2
  fi
  if [ $result -ne 0 ]; then
     exit $result
  fi
  cnt=`ls -l $PG_PATH/archive|wc -l`
  if [ $cnt -le 0 ]; then
    exit 3
  fi
  backup_log
else
  echo "DB servic is not started"
  exit 1
fi
