#!/bin/bash
# Script used to import DB base backup

if [ $# -ne 2 ]; then
  echo "Usage: $0 db_base_file db_xlog_file"
  exit 1
fi

BASE_FILE=$1
XLOG_FILE=$2

source /etc/profile

PG_PATH="$CMS_HOME/postgresql"
PSQL_CMD="$PG_PATH/bin/psql"
PCTL_CMD="$PG_PATH/bin/pg_ctl"
DB_DIR="$PG_PATH/data"
XLOG_DIR="$DB_DIR/pg_xlog"
ARCHIVE_DIR="$PG_PATH/archive"
export LD_LIBRARY_PATH="$PG_PATH/lib/"

if [ ! -f $BASE_FILE ]; then
  echo "$BASE_FILE is not a valid file"
  exit 1
fi
if [ ! -f $XLOG_FILE ]; then
  echo "$XLOG_FILE is not a valid file"
  exit 1
fi

# Check whether the Postgresql is running
status=`su postgres -c "$PCTL_CMD status -D $DB_DIR" | grep "PID"`
if [ "$status" ]; then
  echo "Stoping DB service..."
  su postgres -c "$PCTL_CMD stop -D $DB_DIR" > /dev/null 
fi

while [ "$status" ]
do
  sleep 1
  status=`su postgres -c "$PCTL_CMD status -D $DB_DIR" | grep "PID"`
done
echo "DB service stopped"

# Start restoring db data from file
echo "Clearing $DB_DIR..."
rm -rf $DB_DIR
echo "Extracting file to $PG_PATH..."
tar -xmzf $BASE_FILE -C $PG_PATH

echo "Extracting xlog file to $XLOG_DIR..."
rm -rf $ARCHIVE_DIR
tar -xmzf $XLOG_FILE -C $PG_PATH
mkdir -p $XLOG_DIR
cp -f $ARCHIVE_DIR/* $XLOG_DIR/
rm -f $ARCHIVE_DIR/*

# Reset permission
chown -R postgres:postgres $PG_PATH
