#!/bin/sh
# Script used to switch to Slave 

if [ $# -ne 1 ]; then
  echo "Usage: $0 target_ip"
  exit 1
fi

IP=$1
source /etc/profile
PG_PATH="$CMS_HOME/postgresql"
PSQL_CMD="$PG_PATH/bin/psql"
PCTL_CMD="$PG_PATH/bin/pg_ctl"
DB_DIR="$PG_PATH/data"
export LD_LIBRARY_PATH="$PG_PATH/lib/"

TRIGGER_FILE="trigger"
RECOVERY_FILE="recovery.conf"
RECOVERY_DONE="recovery.done"

if [ ! -d $DB_DIR ]; then
  echo "$DB_DIR is not a directory"
  exit 1
fi

# Check whether the Postgresql is running
status=`su postgres -c "$PCTL_CMD status -D $DB_DIR" | grep "PID"`
if [ "$status" ]; then
  echo "Replication should not be enabled when DB service is running"
  exit 1
fi

echo "Creating recovery.conf..."
# Create recovery.conf
cd $DB_DIR
rm -f $RECOVERY_FILE
rm -f $RECOVERY_DONE
rm -f $TRIGGER_FILE
line1="standby_mode = 'on'"
line2="primary_conninfo = '""host=$IP port=5432 user=postgres'"

if [ ${DB_DIR:0-1} == "/" ]; then
  trigger_path="$DB_DIR$TRIGGER_FILE"
else
  trigger_path="$DB_DIR/$TRIGGER_FILE"
fi
line3="trigger_file = '""$trigger_path'"
su postgres -c "echo \"$line1\" >> $RECOVERY_FILE"
su postgres -c "echo \"$line2\" >> $RECOVERY_FILE"
su postgres -c "echo \"$line3\" >> $RECOVERY_FILE"

# Restart DB service if it was previously started
echo "Starting DB service..."
su postgres -c "$PCTL_CMD start -D $DB_DIR"

while [ ! "$status" ]
do
  sleep 1
  status=`su postgres -c "$PCTL_CMD status -D $DB_DIR" | grep "PID"`
done
echo "DB service started"
